import { Cache, Reference, StoreObject, StoreValue } from "@apollo/client";
import { ReadFieldOptions } from "@apollo/client/cache/core/types/common";
import EntityTypeMap from "../entity-store/EntityTypeMap";
export declare enum InvalidationPolicyEvent {
    Write = "Write",
    Evict = "Evict",
    Read = "Read"
}
export declare enum InvalidationPolicyLifecycleEvent {
    Write = "onWrite",
    Evict = "onEvict"
}
export declare enum RenewalPolicy {
    AccessOnly = "access-only",
    AccessAndWrite = "access-and-write",
    WriteOnly = "write-only",
    None = "none"
}
export interface InvalidationPolicies {
    timeToLive?: number;
    renewalPolicy?: RenewalPolicy;
    types?: {
        [typeName: string]: InvalidationPolicy;
    };
}
export interface PolicyActionFields {
    id: string;
    ref: Reference;
    fieldName?: string;
    storeFieldName?: string;
    variables?: Record<string, any>;
}
export declare type PolicyActionEntity = PolicyActionFields & PolicyActionMeta;
export interface PolicyActionMeta {
    parent: PolicyActionFields;
}
export declare type PolicyAction = (cacheOperations: PolicyActionCacheOperations, entity: PolicyActionEntity) => void;
export declare type InvalidationPolicy = {
    [lifecycleEvent in InvalidationPolicyLifecycleEvent]?: {
        [typeName: string]: PolicyAction;
    };
} & {
    timeToLive?: number;
    renewalPolicy?: RenewalPolicy;
};
export declare type CacheOperations = {
    evict: (options: Cache.EvictOptions, fieldName?: string, args?: Record<string, any>) => boolean;
    modify: (options: Cache.ModifyOptions) => boolean;
    readField: (fieldNameOrOptions?: string | ReadFieldOptions | undefined, from?: StoreObject | Reference) => StoreValue | undefined;
};
export declare type PolicyActionCacheOperations = {
    evict: (options: Omit<Cache.EvictOptions, "broadcast">, fieldName?: string, args?: Record<string, any>) => boolean;
    modify: (options: Omit<Cache.ModifyOptions, "broadcast">) => boolean;
    readField: (fieldNameOrOptions?: string | ReadFieldOptions | undefined, from?: StoreObject | Reference) => StoreValue | undefined;
};
export interface InvalidationPolicyManagerConfig {
    policies: InvalidationPolicies;
    cacheOperations: CacheOperations;
    entityTypeMap: EntityTypeMap;
}
export declare type InvalidationPolicyActivation = {
    [key in InvalidationPolicyEvent]: boolean;
};
//# sourceMappingURL=types.d.ts.map